set.camdata.token: set.camdata.token

Description Usage Arguments Examples

Description

Set the personal key token env variable to access NOLA police bodycam DB API. Unless previously loaded onto env, this function should be used prior to using getcamdata. Otherwise, some restrictions may apply to queries.#'

Usage

1

Arguments

token

The token user received after registering at the API's website: https://dev.socrata.com/foundry/data.nola.gov/cntr-x7sf.

Examples

1
set.camdata.token("xxxxxxxx")

danieltadmon/nolacamr documentation built on May 28, 2019, 11:04 p.m.