Description Usage Arguments Examples
Set the personal key token env variable to access NOLA police bodycam DB API. Unless previously loaded onto env, this function should be used prior to using getcamdata. Otherwise, some restrictions may apply to queries.#'
1 | set.camdata.token(token)
|
token |
The token user received after registering at the API's website: https://dev.socrata.com/foundry/data.nola.gov/cntr-x7sf. |
1 | set.camdata.token("xxxxxxxx")
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.